@@ -39,7 +39,7 @@ const xc_func_info_type xc_func_info_mgga_c_hltapw = {
   "Half-and-half meta-LDAized PW correlation by Lehtola and Marques",
   XC_FAMILY_MGGA,
   {&xc_ref_Lehtola2021_943, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {1, names, desc, ltapw_values, set_ext_params_cpy},
   mgga_c_ltapw_init, NULL,
