@@ -22,7 +22,7 @@ const xc_func_info_type xc_func_info_mgga_x_regtpss = {
   "Regularized TPSS",
   XC_FAMILY_MGGA,
   {&xc_ref_Ruzsinszky2012_2078, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
